'use strict';
const Schema = require('mongoose').Schema;
const metaPlugin = require('naf-framework-mongoose/lib/model/meta-plugin');
// 车辆表
const car = {
  onwer: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '机动车所有人', filter: true, required: true },
    row: 1,
  }, // 机动车所有人
  car_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '机动车登记编号', required: true, notable: true },
    row: 2,
  }, // 机动车登记编号
  id_number: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '身份证明代码', required: true },
    row: 3,
  }, // 身份证明代码
  id_name: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '身份证名称', required: true, notable: true },
    row: 4,
  }, // 身份证明名称
  organ: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '登记机关', required: true, notable: true },
    row: 5,
  }, // 登记机关
  r_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '登记日期', required: true, notable: true, type: 'date' },
    row: 6,
  }, // 登记日期
  c_type: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '机动车类别', required: true, notable: true },
    row: 7,
  }, // 机动车类别
  c_doc_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '机动车档案编号', required: true, notable: true },
    row: 8,
  }, // 机动车档案编号
  c_weight: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '机动车整备质量(自重)', required: true, notable: true },
    row: 9,
  }, // 机动车整备质量(自重)
  c_scrap_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '机动车强制报废日期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 10,
  }, // 机动车强制报废日期
  c_examine_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '机动车检验有效期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 11,
  }, // 机动车检验有效期
  r_tran_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '道路运输证编号', required: true, notable: true },
    row: 12,
  }, // 道路运输证编号
  r_examine_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '道路检验有效期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 13,
  }, // 道路检验有效期
  buy_car_taxes_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '车辆购置税完税证明编号', required: true, notable: true },
    row: 14,
  }, // 车辆购置税完税证明编号
  f_company: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险责任公司', required: true, notable: true },
    row: 15,
  }, // 强制险责任公司
  f_tel: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险责任公司服务电话', required: true, notable: true },
    row: 16,
  }, // 强制险责任公司服务电话
  f_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险保险单号', required: true, notable: true },
    row: 17,
  }, // 强制险保险单号
  f_cost: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险费用合计', required: true, notable: true },
    row: 18,
  }, // 强制险费用合计
  f_start_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险起始时间', required: true, notable: true },
    row: 19,
  }, // 强制险起始时间
  f_end_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险截止时间', required: true, notable: true },
    row: 20,
  }, // 强制险截止时间
  f_solve: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险合同争议解决方式', required: true, notable: true },
    row: 21,
  }, // 强制险合同争议解决方式
  f_car_taxes: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险代收车船使用税', required: true, notable: true },
    row: 22,
  }, // 强制险代收车船使用税
  f_sign_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '强制险签单日期', required: true, notable: true },
    row: 23,
  }, // 强制险签单日期
  b_company: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '商业险责任公司名称', required: true, notable: true },
    row: 24,
  }, // 商业险责任公司名称
  b_tel: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '商业险责任公司电话', required: true, notable: true },
    row: 25,
  }, // 商业险责任公司电话
  b_no: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '商业险保险单号', required: true, notable: true },
    row: 26,
  }, // 商业险保险单号
  b_cost: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '商业险费用合计', required: true, notable: true },
    row: 27,
  }, // 商业险费用合计
  b_start_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '商业险起始日期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 28,
  }, // 商业险起始日期
  b_end_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '商业险截止日期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 29,
  }, // 商业险截止日期
  b_solve: {
    type: String,
    required: false,
    maxLength: 200,
    field: { label: '商业险合同争议解决方式', required: true, notable: true },
    row: 30,
  }, // 商业险合同争议解决方式
  b_sign_date: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '商业险签约日期',
      required: true,
      notable: true,
      type: 'date',
    },
    row: 31,
  }, // 商业险签约日期
  remark: {
    type: String,
    required: false,
    maxLength: 200,
    field: {
      label: '备注',
      type: 'textarea',
      options: { autosize: { minRows: 3, maxRows: 5 } },
    },
    row: 32,
  }, // 备注
  status: {
    type: String,
    maxLength: 200,
    default: '0',
    field: {
      label: '状态',
      filter: 'select',
      type: 'radio',
      format: (i => (i === '0' ? '使用' : '禁用')).toString(),
      list: [
        { label: '使用', value: '0' },
        { label: '禁用', value: '1' },
      ],
    },
  }, // 状态:0=>使用;1禁用
};

const schema = new Schema(car, { toJSON: { virtuals: true } });
schema.index({ id: 1 });
schema.plugin(metaPlugin);

module.exports = app => {
  const { mongoose } = app;
  return mongoose.model('Car', schema, 'car');
};
